#
# spec file for package osmo-ggsn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %nil
Name:           osmo-ggsn
%define lname   libgtp6
Version:        1.11.0
Release:        1.1
Summary:        GPRS Support Node
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/openggsn/wiki/OsmoGGSN
Source:         https://github.com/osmocom/osmo-ggsn/archive/%version.tar.gz
Patch1:         build-fixes.diff
Patch2:         ppc64.diff
BuildRequires:  libtool >= 2
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  pkgconfig(libgtpnl) >= 1.2.0
BuildRequires:  pkgconfig(libosmocore) >= 1.9.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.9.0
BuildRequires:  pkgconfig(libosmovty) >= 1.9.0
Obsoletes:      openggsn

%description
Osmo-GGSN is a C-language implementation of a GGSN (Gateway GPRS
Support Node), a core network element of ETSI/3GPP cellular networks
such as GPRS, EDGE, UMTS or HSPA.

%package -n %lname
Summary:        Library implementing GTP between SGSN and GGSN
License:        GPL-2.0-only
Group:          System/Libraries

%description -n %lname
libgtp implements the GPRS Tunneling Protocol between SGSN and GGSN.

%package -n libgtp-devel
Summary:        Development files for the GTP library
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description -n libgtp-devel
libgtp implements the GPRS Tunneling Protocol between SGSN and GGSN.

This subpackage contains libraries and header files for developing
applications that want to make use of libgtp.

%package -n gtp-echo-responder
Summary:        Small program answering GTP ECHO Request with GTP ECHO Response
License:        MIT
Group:          Productivity/Telephony/Utilities

%description -n gtp-echo-responder
Small program answering GTP ECHO Request with GTP ECHO Response for both GTPCv1
and GTPCv2.

%prep
%autosetup -p1
sed -i 's|%_bindir/osmo-ggsn|%_sbindir/osmo-ggsn|g' contrib/systemd/osmo-ggsn.service

%build
echo "%version" >.tarball-version
autoreconf -fi
# bugzilla.opensuse.org/795968 for rationale
%configure \
	--enable-gtp-linux \
	--includedir="%_includedir/%name" \
	--disable-static --docdir="%_docdir/%name" \
	--with-systemdsystemunitdir="%_unitdir"
%make_build

%install
b="%buildroot"
%make_install
find "$b" -type f -name "*.la" -delete -print
install -d "$b/%_sbindir"
ln -s "%_sbindir/service" "$b/%_sbindir/rc%name"
install -d "$b/%_sysconfdir/osmocom"
install -m 0644 doc/examples/osmo-ggsn.cfg "$b/%_sysconfdir/osmocom/osmo-ggsn.cfg"
install -m 0644 doc/examples/sgsnemu.conf "$b/%_sysconfdir/osmocom/sgsnemu.conf"

%pre
%service_add_pre %name.service

%post
%service_add_post %name.service

%preun
%service_del_preun %name.service

%postun
%service_del_postun %name.service

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS README.md
%_sbindir/osmo-ggsn
%_sbindir/sgsnemu
%_mandir/man8/osmo-ggsn.8*
%_mandir/man8/sgsnemu.8*
%_unitdir/%name.service
%_sbindir/rc%name
%dir %_docdir/%name/examples
%_docdir/%name/examples/osmo-ggsn-kernel-gtp.cfg
%_docdir/%name/examples/osmo-ggsn.cfg
%_docdir/%name/examples/sgsnemu.conf
%dir %_sysconfdir/osmocom
%config(noreplace) %_sysconfdir/osmocom/osmo-ggsn.cfg
%config(noreplace) %_sysconfdir/osmocom/sgsnemu.conf

%files -n %lname
%_libdir/libgtp.so.6*

%files -n libgtp-devel
%_includedir/%name/
%_libdir/libgtp.so
%_libdir/pkgconfig/libgtp.pc

%files -n gtp-echo-responder
%_bindir/gtp-echo-responder

%changelog
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.11.0
  * gtp: Add net GTP cause values and a function to check for success
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.10.2
  * doc: running: update kernel-gtp limitations
* Thu May 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.10.1
  * Use rate_ctr for gsn_t available_counters
  * ggsn: Introduce tdef and make it configurable over VTY
  * gtp: Introduce VTY configurable GTP timer X3
- Add ppc64.diff
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.0
  * libgtp: Fix ggsn crash if pdp alloc array is full (PDP_MAX)
  * gtp: Log detection of rx duplicate
  * gtp: Log retrans queue register&free entries
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8.0
  * Fix vty PDP lookups by IMSI
  * apn_start: avoid segfault if missing tun-device
  * Add --vty-ref-mode option
  * ggsn: Reject PDP CTX ACT for static IP addresses
  * gtp: Support tx/rx RAN Information Relay message
  * ggsn: Fix heap-use-after-free during Recovery without
    associated PDP
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.1
  * Support setting rt-prio and cpu-affinity mask through VTY
  * Fix vty PDP lookups by IMSI
  * Prevent Crash in show pdp-context from vty
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * Add Linux network namespace support for TUN device
  * sgsnemu: Implement ping on IPv6 APNs
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.5.0
  * sgsnemu: Fix null-pointer format string argument
  * ggsn, sgsnemu: Drop use of no-op deprecated gtp_retrans* APIs
  * ggsn: Implement echo req/resp and recovery
  * libgtp: Introduce cb_recovery3
  * ggsn_vty.c: Improve output of VTY show pdp-context
  * gtp-kernel.c: Fix wrong use of in46a_from_eua, print IPv6 euas
- Update patch:
  * build-fixes.diff
* Wed Aug 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.4.0
  * ggsn: Add minimalistic PAP support
  * ggsn: More logging from PCO handling (e.g. in case of malconfiguration)
  * osmo-ggsn: fix VTY command for getting PDP contexts by APN
  * osmo-ggsn: add VTY command to show PDP context by IPv4
  * gtp: Introduce new pdp APIs (and deprecate old ones) to support multiple GSN
* Sat Jul 27 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation of the tests
  See: https://osmocom.org/issues/4114
* Tue Feb  5 2019 mardnh@gmx.de
- Update to new upstream release 1.3.0
  * ggsn: ctrl iface: listen on IP configured by VTY
  * gtp: Allow recv DEL CTX REQ in sgsn and DEL CTX RSP in ggsn
  * gtp: Log ignore CTX DEL REQ due to no teardown and only 1
    ctxactive
  * gtp: Add new API to avoid freeing pdp contexts during
    DEL CTX REQ
  * fix support for multiple IPCP in PDP protocol configuration
    options
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.2.2
  * Add support for IPv4v6 End User Addresses
  * ggsn: Add 'ipv6 link-local' vty cmd
  * Add talloc context introspection via VTY
- Remove 0001-fix-compiler-warnings-return-0-in-main-in-3-tests.patch
  (merged)
* Fri Dec 29 2017 mardnh@gmx.de
- Use systemd service file from tarball
- Fix URL
- Use correct libversion
- Minor specfile cleanup
- Disable kernel-gtp support
- Add patch:
  - 0001-fix-compiler-warnings-return-0-in-main-in-3-tests.patch
* Thu Dec 28 2017 jengelh@inai.de
- Update to new upstream release 1.1.0
  * sgsnemu: Add IPv6 support via tun device and "-t v6 --createif"
  * Allow Common flags 0x94 and ignore them in PDP activation
  * gtpie.h: Add IE identifier definitions up to 29.60 v11.8.0
    Release 11
  * sgsnemu: Add "--tun-device" option to specify TUN device name
  * ggsn: Avoid crash on wrong EUA type
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 1.0.0.30
* Sat Apr 29 2017 jengelh@inai.de
- Initial package (version 0.93.7) for build.opensuse.org
- Add build-fixes.diff
